@@ -138,9 +138,22 @@ class CustomizeLogger:
         if isinstance(level, str):
             level = level.upper()
         logger.remove()
-        if not hasattr(logger.__class__, 'dev'):
-            logger.level(name='DEV', no=19)
+        # if not hasattr(logger.__class__, 'dev'):
+        try:
+            dev_level = logger.level(name='DEV', no=19, color="<blue>", icon="@")
             logger.__class__.dev = functools.partialmethod(logger.__class__.log, 'DEV')
+            logger.add(
+                sys.stdout,
+                enqueue=True,
+                backtrace=True,
+                colorize=True,
+                level=19,
+                format=cls.logger_formatter,
+            )
+        except Exception as e:
+            pass
+        #     print("Error adding DEV level to logger: ", e) 
+        #     # pass
         logger.add(
             sys.stdout,
             enqueue=True,
